@@ -10,7 +10,6 @@ macro_rules! ACCOUNT_STRING {
     };
 }
 
-#[macro_use]
 macro_rules! pubkey {
     ($arg:expr, $help:expr) => {
         $arg.takes_value(true)
@@ -19,9 +18,6 @@ macro_rules! pubkey {
     };
 }
 
-#[macro_use]
-extern crate const_format;
-
 extern crate serde_derive;
 
 pub mod checks;
